import QtQuick 1.0
import Widgets 0.1


Item {
    id: dashBar

    property variant model
    property int currentIndex

    property int initialHeight: units.dp(8/1.5)
    property int maxHeight: units.dp(50)

    width: units.dp(320)
    height: initialHeight
    Behavior on height {NumberAnimation { duration: 300; easing.type: Easing.OutQuad}}

    state: "initial"

    signal itemSelected(int index)

    function startNavigation() {
        timeout.stop()
        dashBar.state = "navigation"
    }

    function stopNavigation() {
        timeout.restart()
    }

    function finishNavigation() {
        dashBar.state = "initial"
    }



    Rectangle {
        color: "black"
        anchors.fill: parent

        Row {
            width: childrenRect.width
            height: parent.height
            Repeater {
                id: repeater
                model: dashBarModel
                delegate: Item {
                    width: dashBar.width / dashBarModel.count
                    height: parent.height
                    clip: true
                    ImageMipmap {
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.top: parent.top
                        anchors.topMargin: units.dp(20/1.5)
                        resource: "graphics/dashBar/" + iconName
                        height: dashBar.maxHeight / 2.5
                        width: height * sourceSize.width / sourceSize.height
                        opacity: index == currentIndex ? 1 : 0.5
                        smooth: true
                    }
                    MouseArea {
                        anchors.fill: parent
                        onPressed: {
                            if (dashbar.state == "initial") {
                                dashbar.state = "navigation"
                                mouse.accepted = false
                            }
                        }

                        onClicked: {
                            timeout.restart()
                            dashBar.itemSelected(index)
                        }
                    }
                }
            }
        }
    }

    ListModel {
        id: dashBarModel

        ListElement {
            iconName: "music_lense_icon.png"
        }
        ListElement {
            iconName: "people_lense_icon.png"
        }
        ListElement {
            iconName: "home_lense_icon.png"
        }
        ListElement {
            iconName: "app_lense_icon.png"
        }
        ListElement {
            iconName: "video_lense_icon.png"
        }
    }

    Rectangle {
        id: orangeBar
        color: "#ff7c00"
        height: parent.initialHeight
        width: dashBar.width / model.count
        anchors.bottom: parent.bottom
        x: currentIndex * width

        Behavior on x {NumberAnimation { duration: 150; easing.type: Easing.OutCubic}}
    }



    Timer {
        id: timeout
        interval: 1500
        running: false
        repeat: false
        onTriggered: finishNavigation()
    }

    states: [
        State {
            name: "initial"
            PropertyChanges {
                target: dashBar
                height: initialHeight
            }
        },
        State {
            name: "navigation"
            PropertyChanges {
                target: dashBar
                height: maxHeight
            }
        }
    ]
}

//Item {
//    id: dashBar
//    width: 480
//    height: 84
//    property ListModel model

//    Rectangle {
//        id: background
//        color: "#111111"
//        opacity: 0.8
//        anchors.fill: parent
//    }

//    ListView {
//        id: dashBarList
//        anchors.fill: parent
//        y: parent.height
//        model: dashBar.model
//        delegate: lenseDelegate
//        orientation: ListView.Horizontal
//        boundsBehavior: Flickable.StopAtBounds
//        flickDeceleration: 5000
//        snapMode: ListView.SnapToItem
//        highlightMoveDuration: 50
//        currentIndex: model.focusIndex

//        highlight:
//            ImageMipmap {
//                resource: "graphics/highlighttriangle.png"
//                smooth: true
//            }
//        focus: true

//        onCurrentIndexChanged: {
//            //prototype.dashData.focusIndex = currentIndex
//        }

//        Behavior on y {NumberAnimation{duration: 150; easing.type: Easing.OutQuad}}


//    }

//    Component {
//        id: lenseDelegate
//        Item {
//            width: 96
//            height: 84
//            ImageMipmap {
//                id: lenseImageId
//                anchors.centerIn: parent
//                resource: lenseImage
//                sourceSize.width: 36
//                sourceSize.height: 36
//                visible: lenseImage != ""
//                smooth: true
//                opacity: dashBarList.currentIndex == index ? 1 : 0.6
//            }

//            MouseArea {
//                anchors.fill: parent
//                onClicked:  {
//                    dashBar.model.focusIndex = index;
//                }
//            }
//        }
//    }
//}
